==> whois_sdk_openapi-0.0.35.tar.gz: whois_sdk_openapi-0.0.35/README.md <==
# WhoisfreaksOpenapi Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-Built%20with%20Fern-brightgreen)](https://buildwithfern.com?utm_source=github&utm_medium=github&utm_campaign=readme&utm_source=https%3A%2F%2Fgithub.com%2Fqasimleoo%2Fwhois-sdk-openapi)
[![pypi](https://img.shields.io/pypi/v/whois-sdk-openapi)](https://pypi.python.org/pypi/whois-sdk-openapi)

The WhoisfreaksOpenapi Python library provides convenient access to the WhoisfreaksOpenapi API from Python.

## Installation

```sh
pip install whois-sdk-openapi
```

## Reference

A full reference for this library is available [here](./reference.md).

## Usage

Instantiate and use the client with the following:

```python
from whoisfreaks_openapi import WhoisfreaksOpenapiApi
client = WhoisfreaksOpenapiApi()
client.get_live_historical_or_reverse_whois(whois="live", domain_name='whoisfreaks.com', keyword='whois', email='abc@xyz.com', owner='ejaz', company='jfreaks', )
```

## Async Client

The SDK also exports an `async` client so that you can make non-blocking calls to our API.

```python
from whoisfreaks_openapi import AsyncWhoisfreaksOpenapiApi
import asyncio
client = AsyncWhoisfreaksOpenapiApi()
async def main() -> None:
    await client.get_live_historical_or_reverse_whois(whois="live", domain_name='whoisfreaks.com', keyword='whois', email='abc@xyz.com', owner='ejaz', company='jfreaks', )
asyncio.run(main())```

## Exception Handling

When the API returns a non-success status code (4xx or 5xx response), a subclass of the following error
will be thrown.

```python
from whoisfreaks_openapi.core.api_error import ApiError
try:
    client.get_live_historical_or_reverse_whois(...)
except ApiError as e:
    print(e.status_code)
    print(e.body)
```

## Advanced

### Access Raw Response Data

The SDK provides access to raw response data, including headers, through the `.with_raw_response` property.
The `.with_raw_response` property returns a "raw" client that can be used to access the `.headers` and `.data` attributes.

```python
from whoisfreaks_openapi import WhoisfreaksOpenapiApi
client = WhoisfreaksOpenapiApi(..., )
response = client.with_raw_response.get_live_historical_or_reverse_whois(...)
print(response.headers)  # access the response headers
print(response.data)  # access the underlying object
```

### Retries

The SDK is instrumented with automatic retries with exponential backoff. A request will be retried as long
as the request is deemed retryable and the number of retry attempts has not grown larger than the configured
retry limit (default: 2).

A request is deemed retryable when any of the following HTTP status codes is returned:

- [408](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408) (Timeout)
- [429](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429) (Too Many Requests)
- [5XX](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500) (Internal Server Errors)

Use the `max_retries` request option to configure this behavior.

```python
client.get_live_historical_or_reverse_whois(..., request_options={
    "max_retries": 1
})
```

### Timeouts

The SDK defaults to a 60 second timeout. You can configure this with a timeout option at the client or request level.

```python

from whoisfreaks_openapi import WhoisfreaksOpenapiApi
client = WhoisfreaksOpenapiApi(..., timeout=20.0, )

# Override timeout for a specific method
client.get_live_historical_or_reverse_whois(..., request_options={
    "timeout_in_seconds": 1
})
```

### Custom Client

You can override the `httpx` client to customize it for your use-case. Some common use-cases include support for proxies
and transports.

```python
from whoisfreaks_openapi import WhoisfreaksOpenapiApi
import httpx
client = WhoisfreaksOpenapiApi(..., httpx_client=httpx.Client(proxies="http://my.test.proxy.example.com", transport=httpx.HTTPTransport(local_address="0.0.0.0"), ))```

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically.
Additions made directly to this library would have to be moved over to our generation code,
otherwise they would be overwritten upon the next generated release. Feel free to open a PR as
a proof of concept, but know that we will not be able to merge it as-is. We suggest opening
an issue first to discuss with us!

On the other hand, contributions to the README are always very welcome!

==> whois_sdk_openapi-0.0.37.tar.gz: whois_sdk_openapi-0.0.37/README.md <==
# Whoisfreaks Python Library

[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-Built%20with%20Fern-brightgreen)](https://buildwithfern.com?utm_source=github&utm_medium=github&utm_campaign=readme&utm_source=https%3A%2F%2Fgithub.com%2Fqasimleoo%2Fwhois-sdk-openapi)
[![pypi](https://img.shields.io/pypi/v/whois-sdk-openapi)](https://pypi.python.org/pypi/whois-sdk-openapi)

The Whoisfreaks Python library provides convenient access to the Whoisfreaks API from Python.

## Installation

```sh
pip install whois-sdk-openapi
```

## Reference

A full reference for this library is available [here](./reference.md).

## Usage

Instantiate and use the client with the following:

```python
from whoisfreaks import WhoisfreaksApi
client = WhoisfreaksApi()
client.live_whois_lookup(whois='whois', api_key='apiKey', domain_name='domainName', )
```

## Async Client

The SDK also exports an `async` client so that you can make non-blocking calls to our API.

```python
from whoisfreaks import AsyncWhoisfreaksApi
import asyncio
client = AsyncWhoisfreaksApi()
async def main() -> None:
    await client.live_whois_lookup(whois='whois', api_key='apiKey', domain_name='domainName', )
asyncio.run(main())```

## Exception Handling

When the API returns a non-success status code (4xx or 5xx response), a subclass of the following error
will be thrown.

```python
from whoisfreaks.core.api_error import ApiError
try:
    client.live_whois_lookup()
except ApiError as e:
    print(e.status_code)
    print(e.body)
```

## Advanced

### Access Raw Response Data

The SDK provides access to raw response data, including headers, through the `.with_raw_response` property.
The `.with_raw_response` property returns a "raw" client that can be used to access the `.headers` and `.data` attributes.

```python
from whoisfreaks import WhoisfreaksApi
client = WhoisfreaksApi(..., )
response = client.with_raw_response.live_whois_lookup()
print(response.headers)  # access the response headers
print(response.data)  # access the underlying object
```

### Retries

The SDK is instrumented with automatic retries with exponential backoff. A request will be retried as long
as the request is deemed retryable and the number of retry attempts has not grown larger than the configured
retry limit (default: 2).

A request is deemed retryable when any of the following HTTP status codes is returned:

- [408](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408) (Timeout)
- [429](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429) (Too Many Requests)
- [5XX](https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500) (Internal Server Errors)

Use the `max_retries` request option to configure this behavior.

```python
client.live_whois_lookup(request_options={
    "max_retries": 1
})
```

### Timeouts

The SDK defaults to a 60 second timeout. You can configure this with a timeout option at the client or request level.

```python

from whoisfreaks import WhoisfreaksApi
client = WhoisfreaksApi(..., timeout=20.0, )

# Override timeout for a specific method
client.live_whois_lookup(request_options={
    "timeout_in_seconds": 1
})
```

### Custom Client

You can override the `httpx` client to customize it for your use-case. Some common use-cases include support for proxies
and transports.

```python
from whoisfreaks import WhoisfreaksApi
import httpx
client = WhoisfreaksApi(..., httpx_client=httpx.Client(proxies="http://my.test.proxy.example.com", transport=httpx.HTTPTransport(local_address="0.0.0.0"), ))```

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically.
Additions made directly to this library would have to be moved over to our generation code,
otherwise they would be overwritten upon the next generated release. Feel free to open a PR as
a proof of concept, but know that we will not be able to merge it as-is. We suggest opening
an issue first to discuss with us!

On the other hand, contributions to the README are always very welcome!
